@@ -14,6 +14,6 @@ if __name__ == "__main__":
     print("0.2 s:", get_unit("0.2 s"))
     print("0.2 m:", get_unit("0.2 m"))
 
-    sleep_func = timed(sleep_func, unit=Unit.minute, estimate=True)
+    sleep_func = timed(sleep_func, unit=Unit.MINUTE, estimate=True)
     runtime = sleep_func()
     print(f"{runtime}: {get_unit(runtime)} or {runtime.unit}")
