@@ -12,16 +12,14 @@ def return_func():
 
 
 if __name__ == "__main__":
-    sleep_func = timed(sleep_func, unit=Unit.second, number=1)
+    sleep_func = timed(sleep_func, unit=Unit.SECOND, number=1)
     runtime = sleep_func()
     print("Runtime of sleep_func:", runtime)
-    print()
 
     return_func = timed(return_func, enable_return=True)
     runtime, ret = return_func()
     print("Runtime of return_func:", runtime)
     print("Result of return_func:", ret)
-    print()
 
     timed_print = timed(print)
     runtime = timed_print("hello")
