@@ -4,54 +4,55 @@ from argparse import ArgumentParser, RawTextHelpFormatter
 from contextlib import contextmanager
 from importlib import import_module
 from re import findall, sub
-from types import FunctionType, ModuleType
-from typing import Dict, Union
+from types import ModuleType
+from typing import Callable, Dict, Union
 
 from functimer import TimingException, Unit, timed
 from functimer.classes import Result
 
 unit_map: Dict[str, Unit] = {
-    "ns": Unit.nanosecond,
-    "ms": Unit.microsecond,
-    "Ms": Unit.millisecond,
-    "s": Unit.second,
-    "m": Unit.minute,
+    "ns": Unit.NANOSECOND,
+    "ms": Unit.MICROSECOND,
+    "Ms": Unit.MILLISECOND,
+    "s": Unit.SECOND,
+    "m": Unit.MINUTE,
 }
 
 RE_ARGS = r"\((.*?)\)"
 RE_LAMBDA = r"\((.*)\)\s*\((.*)\)"
 
 
-def parse_unit(s: str) -> Unit:
+def parse_unit(string: str) -> Unit:
     try:
-        return unit_map[s]
+        return unit_map[string]
     except KeyError:
         try:
-            return Unit[s]
+            return Unit[string]
         except KeyError:
             raise ValueError()
 
 
-def parse_int(s: str) -> int:
-    return int(s.replace(",", ""))
-
-
-@contextmanager
-def create_local(func_chain: str, **kwargs) -> Dict[str, Union[ModuleType, FunctionType]]:
+@contextmanager  # type: ignore
+def localized_module(  # type: ignore
+    func_chain: str, **kwargs
+) -> Dict[str, Union[ModuleType, Callable]]:
     try:
         method = getattr(builtins, func_chain)
-        local = {method.__name__: timed(method, **kwargs, enable_return=True)}
-        yield local
+        builtin_local: Dict[str, Callable] = {
+            method.__name__: timed(method, **kwargs, enable_return=True)
+        }
+        yield builtin_local
     except AttributeError:
-        module, *subattrs, method = func_chain.split(".")
-        module = import_module(module)
-        local = {module.__name__: module}
-        for submodule in subattrs:
+        module_name, *sub_attrs, method = func_chain.split(".")
+        module = import_module(module_name)
+        module_local: Dict[str, ModuleType] = {module.__name__: module}
+        for submodule in sub_attrs:
             module = getattr(module, submodule)
-        store_method = getattr(module, method)
-        setattr(module, method, timed(store_method, **kwargs, enable_return=True))
-        yield local
-        setattr(module, method, store_method)
+        stored_method = getattr(module, method)
+        setattr(module, method, timed(stored_method, **kwargs, enable_return=True))
+        yield module_local
+        # Prevent Mangling of Modules in memory
+        setattr(module, method, stored_method)
 
 
 def exec_func(func: str, **kwargs) -> Result:
@@ -60,7 +61,9 @@ def exec_func(func: str, **kwargs) -> Result:
 
     if not func.startswith("(lambda"):
         func_chain = sub(RE_ARGS, "", func)
-        with create_local(func_chain, **kwargs) as local:
+
+        local: Dict[str, Union[ModuleType, Callable]]
+        with localized_module(func_chain, **kwargs) as local:
             return eval(func, globals(), local)
     else:
         lamb, args = findall(RE_LAMBDA, func)[0]
@@ -102,7 +105,7 @@ def cli():
         "-u",
         "--unit",
         type=parse_unit,
-        default=Unit.microsecond,
+        default=Unit.MICROSECOND,
         help=f"Set the resulting unit, defaults to microsecond. "
         f"({', '.join(list(unit_map.keys()))})",
     )
@@ -111,7 +114,7 @@ def cli():
         "-n",
         "--number",
         metavar="int",
-        type=parse_int,
+        type=lambda s: int(s.replace(",", "")),
         default=10_000,
         help="Set the number of times to execute.",
     )
@@ -123,7 +126,8 @@ def cli():
     )
 
     print(
-        f"{'Average' if not args.estimate else 'Estimated'} runtime of {args.number:,} executions: {runtime}"
+        f"{'Average' if not args.estimate else 'Estimated'} "
+        f"runtime of {args.number:,} executions: {runtime}"
     )
     if args.ret:
         print(f"{args.func} -> {repr(ret)}")
